/*
 * Copyright 2008-2009 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "CoinListModel.h"

// Sigmodr tree includes
#include "CoinListItemModel.h"
#include "GroupModel.h"

// Sigmodr widget includes
#include <sigmodr/widgets/CoinListUI.h>

// Sigmod includes
#include <sigmod/CoinList.h>
#include <sigmod/CoinListItem.h>

// KDE includes
#include <KMenu>

using namespace Sigmod;
using namespace Sigmodr::Widgets;
using namespace Sigmodr::Tree;

CoinListModel::CoinListModel(BaseModel* parent, CoinList* coinList) :
        GroupObjectModel(parent, coinList)
{
    setupData();
}

CoinListModel::~CoinListModel()
{
    clearData();
}

QVariant CoinListModel::data(int role) const
{
    if (role == Qt::DisplayRole)
        return qobject_cast<CoinList*>(m_object)->name();
    else if (role == BaseModel::XmlRole)
    {
        QDomDocument xml(m_object->className());
        xml.appendChild(m_object->save());
        return xml.toString();
    }
    else if (role == BaseModel::WidgetRole)
    {
        QWidget* widget = new CoinListUI(qobject_cast<CoinList*>(m_object), NULL);
        return QVariant::fromValue(widget);
    }
    else if (role == BaseModel::ContextMenuRole)
    {
        KMenu* menu = new KMenu;
        menu->addAction("&Add Object", this, SLOT(addObject()));
        menu->addSeparator();
        menu->addAction("&Delete Coin List", this, SLOT(deleteSelf()));
        return QVariant::fromValue(menu);
    }
    return GroupObjectModel::data(role);
}

bool CoinListModel::setData(const QVariant& value, int role)
{
    if (role == BaseModel::XmlRole)
    {
        QString data = value.toString();
        if (!data.isEmpty())
        {
            QDomDocument xml;
            if (loadFromData(data, &xml))
            {
                if (xml.doctype().name() == m_object->className())
                {
                    clearData();
                    m_object->load(xml.documentElement());
                    setupData();
                    return true;
                }
                else if (xml.doctype().name() == "CoinListItem")
                {
                    addObject(qobject_cast<CoinList*>(m_object)->newItem(xml.documentElement()));
                    return true;
                }
            }
        }
    }
    return false;
}

QString CoinListModel::types() const
{
    return type().append(QString(";CoinListItem"));
}

void CoinListModel::addObject(Object* object)
{
    if (!object)
        object = qobject_cast<CoinList*>(m_object)->newItem();
    if (object->className() == "CoinListItem")
        addChild(new CoinListItemModel(this, qobject_cast<CoinListItem*>(object)));
}

void CoinListModel::deleteObject(BaseModel* model)
{
    const int index = find(model);
    if (0 <= index)
    {
        qobject_cast<CoinList*>(m_object)->deleteItem(index);
        m_objects[index]->deleteLater();
        m_objects.removeAt(index);
        childRowChanged(index);
    }
}

void CoinListModel::deleteSelf()
{
    qobject_cast<GroupModel*>(m_parent)->deleteObject(this);
}

void CoinListModel::setupData()
{
    CoinList* coinList = qobject_cast<CoinList*>(m_object);
    for (int i = 0; i < coinList->itemCount(); ++i)
        addChild(new CoinListItemModel(this, coinList->item(i)));
}
