/*
 * Copyright 2008-2009 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MapWildListEncounterModel.h"

// Sigmodr tree includes
#include "GroupObjectModel.h"

// Sigmodr widget includes
#include <sigmodr/widgets/MapWildListEncounterUI.h>

// Sigmod includes
#include <sigmod/Game.h>
#include <sigmod/MapWildList.h>
#include <sigmod/MapWildListEncounter.h>
#include <sigmod/Species.h>

// KDE includes
#include <KMenu>

using namespace Sigmod;
using namespace Sigmodr::Widgets;
using namespace Sigmodr::Tree;

MapWildListEncounterModel::MapWildListEncounterModel(BaseModel* parent, MapWildListEncounter* encounter) :
        ObjectModel(parent, encounter)
{
}

QVariant MapWildListEncounterModel::data(int role) const
{
    if (role == Qt::DisplayRole)
    {
        const Species* species = m_object->game()->speciesById(qobject_cast<MapWildListEncounter*>(m_object)->species());
        if (species)
            return species->name();
        return "";
    }
    else if (role == BaseModel::XmlRole)
    {
        QDomDocument xml(m_object->className());
        xml.appendChild(m_object->save());
        return xml.toString();
    }
    else if (role == BaseModel::WidgetRole)
    {
        QWidget* widget = new MapWildListEncounterUI(qobject_cast<MapWildListEncounter*>(m_object), NULL);
        return QVariant::fromValue(widget);
    }
    else if (role == BaseModel::ContextMenuRole)
    {
        KMenu* menu = new KMenu;
        menu->addAction("&Delete Encounter", this, SLOT(deleteSelf()));
        return QVariant::fromValue(menu);
    }
    return ObjectModel::data(role);
}

void MapWildListEncounterModel::deleteSelf()
{
    qobject_cast<GroupObjectModel*>(m_parent)->deleteObject(this);
}
