/*
 * Copyright 2008-2009 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "ObjectModel.h"

// Sigmod includes
#include <sigmod/Object.h>

// Qt includes
#include <QtXml/QDomDocument>

using namespace Sigmod;
using namespace Sigmodr::Tree;

ObjectModel::ObjectModel(BaseModel* parent, Object* object) :
        BaseObjectModel(parent, object)
{
}

ObjectModel::~ObjectModel()
{
}

int ObjectModel::rowCount() const
{
    return 0;
}

QVariant ObjectModel::data(int role) const
{
    return BaseObjectModel::data(role);
}

bool ObjectModel::setData(const QVariant& value, int role)
{
    if (role == BaseModel::XmlRole)
    {
        QString data = value.toString();
        if (!data.isEmpty())
        {
            QDomDocument xml;
            if (loadFromData(data, &xml) && (xml.doctype().name() == m_object->className()))
            {
                m_object->load(xml.documentElement());
                return true;
            }
        }
    }
    return false;
}

BaseModel* ObjectModel::childItem(const int row)
{
    Q_UNUSED(row)
    return NULL;
}

QString ObjectModel::types() const
{
    return type();
}
